@@ -91,12 +91,12 @@ class Workflow(Task):
                 getattr(self.inputs,name).set_value(val)
         for name in task.output_controls:
             for c in task.output_controls[name].output_connections:
-                self.add(c.to_port.task)
+                self.add(c.to_port.task())
         #
         for name in task.outputs:
             if len(task.outputs[name].output_connections) > 0:
                 for c in task.outputs[name].output_connections:
-                    self.add(c.to_port.task)
+                    self.add(c.to_port.task())
             else:
                 if name in self._final_task.inputs:
                     raise ValueError("Cannot declare a workplan with multiple output values that share the same name: %s" % name)
